==> alive-progress-2.0.0.tar.gz: alive-progress-2.0.0/tests/core/test_hook_manager.py <==
import logging
import sys
from threading import Condition
from contextlib import contextmanager
from unittest import mock

import pytest

from alive_progress.core.hook_manager import buffered_hook_manager


@contextmanager
def hook(hook_manager):
    hook_manager.install()
    yield
    hook_manager.uninstall()


def test_hook_manager_captures_stdout(capsys):
    hook_manager = buffered_hook_manager('nice {}! ', lambda: 35, Condition())
    with hook(hook_manager):
        print('ok')
    assert capsys.readouterr().out == 'nice 35! ok\n'


# I couldn't make this work yet, there's some weird interaction
# between my hook and the pytest one...
def _hook_manager_captures_logging(capsys):
    import sys
    logging.basicConfig(stream=sys.stderr)
    logger = logging.getLogger('?name?')

    hook_manager = buffered_hook_manager('nice {}! ', lambda: 35, Condition())
    with hook(hook_manager):
        logger.error('oops')
    assert capsys.readouterr().err == 'nice 35! ERROR:?name?:oops\n'


def test_hook_manager_captures_multiple_lines(capsys):
    hook_manager = buffered_hook_manager('nice {}! ', lambda: 35, Condition())
    with hook(hook_manager):
        print('ok1\nok2')
    assert capsys.readouterr().out == 'nice 35! ok1\n         ok2\n'


def test_hook_manager_can_be_disabled(capsys):
    hook_manager = buffered_hook_manager('', None, Condition())
    with hook(hook_manager):
        print('ok')
    assert capsys.readouterr().out == 'ok\n'


def test_hook_manager_flush(capsys):
    hook_manager = buffered_hook_manager('', None, Condition())
    with hook(hook_manager):
        print('ok', end='')
        assert capsys.readouterr().out == ''
        hook_manager.flush_buffers()
        assert capsys.readouterr().out == 'ok\n'

    # after used, the buffers should be empty
    hook_manager.flush_buffers()
    assert capsys.readouterr().out == ''


def test_hook_manager_do_clear_line_on_stdout():
    hook_manager = buffered_hook_manager('', None, Condition())
    with hook(hook_manager), mock.patch('alive_progress.core.hook_manager.clear_line') as m_clear:
        print('some')
    m_clear.assert_called()


def test_hook_manager_do_not_flicker_screen_when_logging(capsys):
    logging.basicConfig()
    logger = logging.getLogger()

    hook_manager = buffered_hook_manager('', None, Condition())
    with hook(hook_manager), mock.patch('alive_progress.core.hook_manager.clear_line') as m_clear:
        logger.error('oops')
    m_clear.assert_not_called()


@pytest.fixture
def handlers():
    handlers = (logging.StreamHandler(sys.stderr),
                logging.StreamHandler(sys.stdout),
                logging.FileHandler('/dev/null', delay=True))
    [logging.root.addHandler(h) for h in handlers]
    yield handlers
    [logging.root.removeHandler(h) for h in handlers]


def test_install(handlers):
    hook_manager = buffered_hook_manager('', None, Condition())
    with mock.patch('alive_progress.core.hook_manager._set_stream') as mock_set_stream:
        hook_manager.install()
    mock_set_stream.assert_has_calls(tuple(mock.call(h, mock.ANY) for h in handlers))


def test_uninstall(handlers):
    hook_manager = buffered_hook_manager('', None, Condition())
    with mock.patch('alive_progress.core.hook_manager._set_stream') as mock_set_stream:
        hook_manager.install()
        hook_manager.uninstall()
    mock_set_stream.assert_has_calls(tuple(mock.call(h, mock.ANY) for h in handlers))

==> alive-progress-2.1.0.tar.gz: alive-progress-2.1.0/tests/core/test_hook_manager.py <==
import logging
import sys
from threading import Condition
from contextlib import contextmanager
from unittest import mock

import pytest

from alive_progress.core.hook_manager import buffered_hook_manager
from alive_progress.utils.terminal import FULL, VOID


@contextmanager
def hook(hook_manager):
    hook_manager.install()
    yield
    hook_manager.uninstall()


def test_hook_manager_captures_stdout(capsys):
    hook_manager = buffered_hook_manager('nice {}! ', lambda: 35, Condition(), FULL)
    with hook(hook_manager):
        print('ok')
    assert capsys.readouterr().out == 'nice 35! ok\n'


# I couldn't make this work yet, there's some weird interaction
# between my hook and the pytest one...
def _hook_manager_captures_logging(capsys):
    import sys
    logging.basicConfig(stream=sys.stderr)
    logger = logging.getLogger('?name?')

    hook_manager = buffered_hook_manager('nice {}! ', lambda: 35, Condition(), FULL)
    with hook(hook_manager):
        logger.error('oops')
    assert capsys.readouterr().err == 'nice 35! ERROR:?name?:oops\n'


def test_hook_manager_captures_multiple_lines(capsys):
    hook_manager = buffered_hook_manager('nice {}! ', lambda: 35, Condition(), FULL)
    with hook(hook_manager):
        print('ok1\nok2')
    assert capsys.readouterr().out == 'nice 35! ok1\n         ok2\n'


def test_hook_manager_can_be_disabled(capsys):
    hook_manager = buffered_hook_manager('', None, Condition(), FULL)
    with hook(hook_manager):
        print('ok')
    assert capsys.readouterr().out == 'ok\n'


def test_hook_manager_flush(capsys):
    hook_manager = buffered_hook_manager('', None, Condition(), FULL)
    with hook(hook_manager):
        print('ok', end='')
        assert capsys.readouterr().out == ''
        hook_manager.flush_buffers()
        assert capsys.readouterr().out == 'ok\n'

    # after used, the buffers should be empty
    hook_manager.flush_buffers()
    assert capsys.readouterr().out == ''


def test_hook_manager_do_clear_line_on_stdout():
    hook_manager = buffered_hook_manager('', None, Condition(), VOID)
    m_clear = mock.Mock()
    with hook(hook_manager), mock.patch.dict(VOID.__dict__, clear_line=m_clear):
        print('some')
    m_clear.assert_called()


def test_hook_manager_do_not_flicker_screen_when_logging():
    logging.basicConfig()
    logger = logging.getLogger()

    hook_manager = buffered_hook_manager('', None, Condition(), VOID)
    m_clear = mock.Mock()
    with hook(hook_manager), mock.patch.dict(VOID.__dict__, clear_line=m_clear):
        logger.error('oops')
    m_clear.assert_not_called()


@pytest.fixture
def handlers():
    handlers = (logging.StreamHandler(sys.stderr),
                logging.StreamHandler(sys.stdout),
                logging.FileHandler('/dev/null', delay=True))
    [logging.root.addHandler(h) for h in handlers]
    yield handlers
    [logging.root.removeHandler(h) for h in handlers]


def test_install(handlers):
    hook_manager = buffered_hook_manager('', None, Condition(), FULL)
    with mock.patch('alive_progress.core.hook_manager._set_stream') as mock_set_stream:
        hook_manager.install()
    mock_set_stream.assert_has_calls(tuple(mock.call(h, mock.ANY) for h in handlers))


def test_uninstall(handlers):
    hook_manager = buffered_hook_manager('', None, Condition(), FULL)
    with mock.patch('alive_progress.core.hook_manager._set_stream') as mock_set_stream:
        hook_manager.install()
        hook_manager.uninstall()
    mock_set_stream.assert_has_calls(tuple(mock.call(h, mock.ANY) for h in handlers))
